Collect GTFS-RT data from a JSON feed at regular intervals
Source:R/rt_collect_json.R
rt_collect_json.RdCollect GTFS-RT data from a JSON feed at regular intervals
Usage
rt_collect_json(
gtfs_rt_url,
destination_file,
header_key = "header",
entity_key = "entity",
fields_collect = c("id", "vehicle.trip.trip_id", "vehicle.position.latitude",
"vehicle.position.longitude", "vehicle.position.speed", "vehicle.timestamp",
"vehicle.current_status", "vehicle.current_stop_sequence", "vehicle.stop_id"),
scrape_interval = 60,
log_file = NA,
headers = NULL
)Arguments
- gtfs_rt_url
String. URL of the GTFS-RT feed in JSON format.
- destination_file
String. File to save the downloaded GTFS-RT data. Content is appended in each iteration.
- header_key
String (Default "header"). Key in the JSON corresponding to the feed header. Set to NA if not present.
- entity_key
String (Default "entity"). Key in the JSON corresponding to the feed entities. Set to NA if response is a flat list. Use "." for nested keys.
- fields_collect
Character vector. Fields to extract from each entity in the feed. Use "." for nested keys.
- scrape_interval
Integer (Default 60). Interval in seconds between each download. Negative to run only once.
- log_file
String (Optional). Path to a log file to save download logs.
- headers
Named list or character vector (Optional). Custom HTTP headers for credentials when accessing the GTFS-RT feed URL.
Details
Downloads GTFS-RT data from the specified URL at regular intervals and saves them to the destination file.
This function will run indefinitely until manually stopped (CTRL + C).
Examples
# Create file
destination_file <- withr::local_tempfile(fileext = ".csv")
# Collect data
GTFShift::rt_collect_json(
gtfs_rt_url = "https://go.tmlmobilidade.pt/hub/api/v1/realtime/vehicles/positions/gtfs",
entity_key = "data.entity",
destination_file = destination_file,
scrape_interval = -1 # Negative to run only once
)
#> [2026-08-27 16:43:55] Starting GTFS-RT data collection from https://go.tmlmobilidade.pt/hub/api/v1/realtime/vehicles/positions/gtfs
#> [20260827_164355] Iteration 1 completed
#> [1] "/tmp/RtmpGgUISp/file1f216996f225.csv"
# Read data
collection <- read.csv(destination_file)
names(collection)
#> [1] "id" "vehicle.trip.trip_id"
#> [3] "vehicle.position.latitude" "vehicle.position.longitude"
#> [5] "vehicle.position.speed" "vehicle.timestamp"
#> [7] "vehicle.current_status" "vehicle.current_stop_sequence"
#> [9] "vehicle.stop_id"
head(
collection |>
dplyr::select("vehicle.trip.trip_id", "vehicle.position.latitude", "vehicle.position.longitude")
)
#> vehicle.trip.trip_id vehicle.position.latitude
#> 1 [F1M13][A2L1N]4704_0_2|2700|1735 38.78615
#> 2 [F1M13][A2L1N]4600_0_1|2700|1700 38.69729
#> 3 [0277F][BNA17]2537_0_1|1|3|1740 38.86569
#> 4 [F1M13][A2L1N]4432_0_1|2700|1740 38.52625
#> 5 [F1M13][A2L1N]4704_0_2|2700|1720 38.70693
#> 6 [F1M13][A2L1N]4102_0_2|2700|1740 38.68089
#> vehicle.position.longitude
#> 1 -9.091165
#> 2 -8.944952
#> 3 -9.060261
#> 4 -8.891690
#> 5 -8.960492
#> 6 -8.985577