Collect GTFS-RT data from a Protocol Buffers feed at regular intervals
Source:R/rt_collect_protobuf.R
rt_collect_protobuf.RdCollect GTFS-RT data from a Protocol Buffers feed at regular intervals
Usage
rt_collect_protobuf(
gtfs_rt_url,
destination_file,
fields_collect = c("id", "vehicle.trip.trip_id", "vehicle.position.latitude",
"vehicle.position.longitude", "vehicle.position.speed", "vehicle.timestamp",
"vehicle.current_status", "vehicle.current_stop_sequence", "vehicle.stop_id"),
scrape_interval = 60,
log_file = NA,
headers = NULL
)Arguments
- gtfs_rt_url
String. URL of the Protocol Buffers GTFS-RT feed.
- destination_file
String. File to save the downloaded GTFS-RT data. Content is appended in each iteration.
- fields_collect
Character vector. Fields to extract from each entity in the feed.
- scrape_interval
Integer (Default 60). Interval in seconds between each download. Negative to run only once.
- log_file
String (Optional). Path to a log file to save download logs.
- headers
Named list or character vector (Optional). Custom HTTP headers for credentials when accessing the GTFS-RT feed URL.
Details
Downloads GTFS-RT data from the specified URL at regular intervals and saves them to the destination file.
This function will run indefinitely until manually stopped (CTRL + C).
Examples
# Create file
destination_file <- withr::local_tempfile(fileext = ".csv")
# Collect data
GTFShift::rt_collect_protobuf(
gtfs_rt_url = "https://go.tmlmobilidade.pt/hub/api/v1/realtime/vehicles/positions/gtfs.pb",
destination_file = destination_file,
scrape_interval = -1 # Negative to run only once
)
#> [2026-07-30 16:12:59] Starting GTFS-RT data collection from https://go.tmlmobilidade.pt/hub/api/v1/realtime/vehicles/positions/gtfs.pb
#> [20260730_161259] Iteration 1 completed
#> [1] "/tmp/Rtmpmh4xWj/file1f28c289041.csv"
# Read data
collection <- read.csv(destination_file)
names(collection)
#> [1] "id" "vehicle.trip.trip_id"
#> [3] "vehicle.position.latitude" "vehicle.position.longitude"
#> [5] "vehicle.position.speed" "vehicle.timestamp"
#> [7] "vehicle.current_status" "vehicle.current_stop_sequence"
#> [9] "vehicle.stop_id" "feed_timestamp"
#> [11] "feed_incrementality"
head(
collection |>
dplyr::select("vehicle.trip.trip_id", "vehicle.position.latitude", "vehicle.position.longitude")
)
#> vehicle.trip.trip_id vehicle.position.latitude
#> 1 [07MSC][LA77N]1242_0_1_1630_1659_0_7 38.8496
#> 2 [07MSC][LA77N]1252_0_3_1700_1729_0_7 38.7928
#> 3 [07MSC][LA77N]1601_1_2_1600_1629_0_7 38.7580
#> 4 [07MSC][LA77N]1707_0_1_1630_1659_0_7 38.7742
#> 5 [07MSC][LA77N]1522_0_1_1700_1729_0_7 38.7074
#> 6 [07MSC][LA77N]1117_3_2_1630_1659_0_7 38.7128
#> vehicle.position.longitude
#> 1 -9.4395
#> 2 -9.3736
#> 3 -9.2268
#> 4 -9.2305
#> 5 -9.2257
#> 6 -9.2754